define(
//begin v1.x content
({
	"nodeActions": "Actions ${nodeName}",
	"selectContents": "Sélection de contenus",
	"selectElement": "Sélection d'un élément",
	"deleteElement": "Suppression d'un élément",
	"deleteContents": "Suppression de contenus",
	"moveStart": "Déplacer le curseur vers le début",
	"moveEnd": "Déplacer le curseur vers la fin"
})

//end v1.x content
);
